# coding: utf-8

# flake8: noqa

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0+2468026557"

# Define package exports
__all__ = [
    "CatalogApi",
    "HealthApi",
    "RunsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CatalogSkillEntry",
    "CatalogToolEntry",
    "ChatMessageAttachment",
    "ChatMessageAttachmentType",
    "DynamicSkillInput",
    "HTTPValidationError",
    "HealthResponse",
    "LocationInner",
    "PortalInfo",
    "PortalOwnerInfo",
    "RunAssistantContext",
    "RunCancelResponse",
    "RunChatContext",
    "RunCreateRequest",
    "RunCreateResponse",
    "RunUserContext",
    "SkillsCatalogResponse",
    "ToolsCatalogResponse",
    "ValidationError",
    "WrappedResponseHealthResponse",
    "WrappedResponseRunCancelResponse",
    "WrappedResponseRunCreateResponse",
    "WrappedResponseSkillsCatalogResponse",
    "WrappedResponseToolsCatalogResponse",
]

# import apis into sdk package
from deep_agent_sdk.api.catalog_api import CatalogApi as CatalogApi
from deep_agent_sdk.api.health_api import HealthApi as HealthApi
from deep_agent_sdk.api.runs_api import RunsApi as RunsApi

# import ApiClient
from deep_agent_sdk.api_response import ApiResponse as ApiResponse
from deep_agent_sdk.api_client import ApiClient as ApiClient
from deep_agent_sdk.configuration import Configuration as Configuration
from deep_agent_sdk.exceptions import OpenApiException as OpenApiException
from deep_agent_sdk.exceptions import ApiTypeError as ApiTypeError
from deep_agent_sdk.exceptions import ApiValueError as ApiValueError
from deep_agent_sdk.exceptions import ApiKeyError as ApiKeyError
from deep_agent_sdk.exceptions import ApiAttributeError as ApiAttributeError
from deep_agent_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from deep_agent_sdk.models.catalog_skill_entry import CatalogSkillEntry as CatalogSkillEntry
from deep_agent_sdk.models.catalog_tool_entry import CatalogToolEntry as CatalogToolEntry
from deep_agent_sdk.models.chat_message_attachment import ChatMessageAttachment as ChatMessageAttachment
from deep_agent_sdk.models.chat_message_attachment_type import ChatMessageAttachmentType as ChatMessageAttachmentType
from deep_agent_sdk.models.dynamic_skill_input import DynamicSkillInput as DynamicSkillInput
from deep_agent_sdk.models.http_validation_error import HTTPValidationError as HTTPValidationError
from deep_agent_sdk.models.health_response import HealthResponse as HealthResponse
from deep_agent_sdk.models.location_inner import LocationInner as LocationInner
from deep_agent_sdk.models.portal_info import PortalInfo as PortalInfo
from deep_agent_sdk.models.portal_owner_info import PortalOwnerInfo as PortalOwnerInfo
from deep_agent_sdk.models.run_assistant_context import RunAssistantContext as RunAssistantContext
from deep_agent_sdk.models.run_cancel_response import RunCancelResponse as RunCancelResponse
from deep_agent_sdk.models.run_chat_context import RunChatContext as RunChatContext
from deep_agent_sdk.models.run_create_request import RunCreateRequest as RunCreateRequest
from deep_agent_sdk.models.run_create_response import RunCreateResponse as RunCreateResponse
from deep_agent_sdk.models.run_user_context import RunUserContext as RunUserContext
from deep_agent_sdk.models.skills_catalog_response import SkillsCatalogResponse as SkillsCatalogResponse
from deep_agent_sdk.models.tools_catalog_response import ToolsCatalogResponse as ToolsCatalogResponse
from deep_agent_sdk.models.validation_error import ValidationError as ValidationError
from deep_agent_sdk.models.wrapped_response_health_response import WrappedResponseHealthResponse as WrappedResponseHealthResponse
from deep_agent_sdk.models.wrapped_response_run_cancel_response import WrappedResponseRunCancelResponse as WrappedResponseRunCancelResponse
from deep_agent_sdk.models.wrapped_response_run_create_response import WrappedResponseRunCreateResponse as WrappedResponseRunCreateResponse
from deep_agent_sdk.models.wrapped_response_skills_catalog_response import WrappedResponseSkillsCatalogResponse as WrappedResponseSkillsCatalogResponse
from deep_agent_sdk.models.wrapped_response_tools_catalog_response import WrappedResponseToolsCatalogResponse as WrappedResponseToolsCatalogResponse



# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist

class DynamicSkillInput(BaseModel):
    """
    A skill passed as inline content, available to the agent at runtime.  # noqa: E501
    """
    name: StrictStr = Field(default=..., description="Unique skill name")
    description: StrictStr = Field(default=..., description="Short description shown in the agent prompt")
    content: StrictStr = Field(default=..., description="Full skill content (markdown)")
    allowed_tools: Optional[conlist(StrictStr)] = Field(default=None, description="Tools this skill may reference")
    __properties = ["name", "description", "content", "allowed_tools"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DynamicSkillInput:
        """Create an instance of DynamicSkillInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DynamicSkillInput:
        """Create an instance of DynamicSkillInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DynamicSkillInput.parse_obj(obj)

        _obj = DynamicSkillInput.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "content": obj.get("content"),
            "allowed_tools": obj.get("allowed_tools")
        })
        return _obj


